pub struct UNARY_MINUS { /* private fields */ }Methods from Deref<Target = Op>
Sourcepub fn match_front(&self, input: &str) -> Option<&str>
pub fn match_front(&self, input: &str) -> Option<&str>
Given a string, returns a matched prefix of that string if the prefix matches one of the operator’s representations and None otherwise.