This module defines the Formatter trait, representing a given output format that can serialize
ASTs. This is where all of the formatting logic is held: ASTs themselves only store the
structure of data, not how that structure is represented.
Traits
- Formatter
- A serializer for
ASTs, controlling how they are displayed to a specific output type T.